==> manaplus-1.2.1.22.tar.bz2: manaplus-1.2.1.22/src/net/manaserv/adminhandler.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2012  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NET_MANASERV_ADMINHANDLER_H
#define NET_MANASERV_ADMINHANDLER_H

#include "net/adminhandler.h"
#include "string"

namespace ManaServ
{

class AdminHandler : public Net::AdminHandler
{
    public:
        AdminHandler();

        void announce(const std::string &text);

        void localAnnounce(const std::string &text);

        void hide(bool hide);

        void kick(int playerId);

        void kick(const std::string &name);

        void ban(int playerId);

        void ban(const std::string &name);

        void unban(int playerId);

        void unban(const std::string &name);

        void mute(int playerId, int type, int limit);

        void warp(std::string map, int x, int y);
};

} // namespace ManaServ

#endif

==> manaplus-1.2.2.19.tar.bz2: manaplus-1.2.2.19/src/net/manaserv/adminhandler.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2012  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NET_MANASERV_ADMINHANDLER_H
#define NET_MANASERV_ADMINHANDLER_H

#include "net/adminhandler.h"
#include "string"

namespace ManaServ
{

class AdminHandler : public Net::AdminHandler
{
    public:
        AdminHandler();

        void announce(const std::string &text);

        void localAnnounce(const std::string &text);

        void hide(bool hide);

        void kick(int playerId);

        void kickName(const std::string &name);

        void ban(int playerId);

        void banName(const std::string &name);

        void unban(int playerId);

        void unbanName(const std::string &name);

        void mute(int playerId, int type, int limit);

        void warp(std::string map, int x, int y);
};

} // namespace ManaServ

#endif
